[![Latest Version](https://img.shields.io/pypi/v/typer-repyt?label=pypi-version&logo=python&style=plastic)](https://pypi.org/project/typer-repyt/)
[![Python Versions](https://img.shields.io/python/required-version-toml?tomlFilePath=https%3A%2F%2Fraw.githubusercontent.com%2Fdusktreader%2Ftyper-repyt%2Fmain%2Fpyproject.toml&style=plastic&logo=python&label=python-versions)](https://www.python.org/)
[![Build Status](https://github.com/dusktreader/typer-repyt/actions/workflows/main.yml/badge.svg)](https://github.com/dusktreader/typer-repyt/actions/workflows/main.yml)
[![Documentation Status](https://github.com/dusktreader/typer-repyt/actions/workflows/docs.yml/badge.svg)](https://dusktreader.github.io/typer-repyt/)


![typer-repyt-logo](https://github.com/dusktreader/typer-repyt/blob/main/docs/source/images/logo-dark.png)

_Tools to extended functionality for typer based CLIs_


## Super-quick Start

Requires: Python 3.12 to 3.13

Install through pip:

```bash
pip install typer-repyt
```


## Documentation

The complete documentation can be found at the
[typer-repyt home page](https://dusktreader.github.io/typer-repyt)


## Demo

To see the features in action, you can run the demo in an isolated environment with `uv`:

```
uvx --from=typer-repyt[demo] typer-repyt-demo
```
